Module: Jekyll

Defined in:
lib/jekyll_relative_urls/jekyll/tags/base.rb,
lib/jekyll_relative_urls/jekyll/url.rb,
lib/jekyll_relative_urls/jekyll/renderer.rb

Overview

Copyright (c) 2019 Sutty [email protected]

This file is part of jekyll-relative-urls

jekyll-relative-urls is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

jekyll-relative-urls is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with jekyll-relative-urls. If not, see https://www.gnu.org/licenses/.

Defined Under Namespace

Modules: Tags Classes: Renderer, URL